limeutils
=========

Limeutils is a small collection of classes and methods for dealing with Redis data and a few other helpful functions. Check out the documentation for information
 . More classes to be added as needed.

This package uses [Pydantic models][pydantic] to validate its data.

Installation
------------

### Install with `pip`

This is the recommended way to install Limeutils.

```
pip install limeutils
```

### Install with repo

```
pip install git+https://github.com/dropkickdev/limeutils.git@develop#egg=limeutils
```

### Install with `git clone`

Simply install from the root folder

```
# This can also be a fork
git clone https://github.com/dropkickdev/limeutils.git

cd limeutils
pip install .
```


[pydantic]: https://pydantic-docs.helpmanual.io/ 'Pydantic'

## Documentation

View the documentation at: https://dropkickdev.github.io/limeutils/
